/* 
 * Interp.java --
 *
 *	This file contains the implementation of the Java API
 *	for creating and controlling Tcl interpreters.
 *
 * Copyright (c) 1995 by Sun Microsystems, Inc.
 *
 * See the file "license.terms" for information on usage and redistribution
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 *
 * SCCS: @(#) Interp.java 1.3 95/12/19 14:34:40
 */

package tcl;
import java.util.Vector;


public class Interp {

    /*
     * Status codes returned in Result.
     */

    public static final int TCL_OK = 0;
    public static final int TCL_ERROR = 1;
    public static final int TCL_RETURN = 2;
    public static final int TCL_BREAK = 3;
    public static final int TCL_CONTINUE = 4;

    /*
     * Flags passed to doOneEvent.  These values may be or'ed together.
     */

    public static final int TCL_DONT_WAIT = (1<<1);
    public static final int TCL_WINDOW_EVENTS = (1<<2);
    public static final int TCL_FILE_EVENTS = (1<<3);
    public static final int TCL_TIMER_EVENTS = (1<<4);
    public static final int TCL_IDLE_EVENTS = (1<<5);
    public static final int TCL_ALL_EVENTS = (~TCL_DONT_WAIT);

    public Interp () {
	commands = new Vector();
	create();
    }

    public native synchronized int eval(String s, Result r);

    public native synchronized void setResult(Value v);

    /*
     * Create a new Tcl command with the given implementation object.
     */

    public native synchronized void createCommand(String s, Command obj);

    /*
     * Process one pending event off the event queue.
     */

    public static native int doOneEvent(int flags);

    /*
     * Private initialization method.
     */

    private native void create();

    /*
     * Private implementation variables.
     */

    private Vector commands;	// Array of Command objects.
    private int interp;		// Interpreter handle.
}

